package org.javabuilders.swing.jide;

import org.javabuilders.BuilderConfig;
import org.javabuilders.swing.SwingJavaBuilder;

import com.jidesoft.editor.ClipboardsDialog;
import com.jidesoft.editor.CodeEditor;
import com.jidesoft.editor.CodeEditorDocumentPane;
import com.jidesoft.editor.CodeEditorPainter;
import com.jidesoft.editor.CodeEditorSearchable;
import com.jidesoft.editor.SyntaxDocument;
import com.jidesoft.editor.margin.AbstractLineMargin;
import com.jidesoft.editor.margin.AbstractMargin;
import com.jidesoft.editor.margin.BraceMatchingMarginPainter;
import com.jidesoft.editor.margin.CodeFoldingMargin;
import com.jidesoft.editor.margin.LineNumberMargin;
import com.jidesoft.editor.margin.LineOffsetMargin;
import com.jidesoft.editor.margin.MarginArea;
import com.jidesoft.editor.marker.MarkerArea;
import com.jidesoft.editor.marker.MarkerEye;
import com.jidesoft.editor.marker.MarkerStripe;
import com.jidesoft.editor.settings.FontPanel;
import com.jidesoft.editor.settings.StyleListPanel;
import com.jidesoft.editor.settings.StylePanel;
import com.jidesoft.editor.status.AbstractCodeEditorStatusBarItem;
import com.jidesoft.editor.status.CaretModelPositionStatusBarItem;
import com.jidesoft.editor.status.CaretOffsetStatusBarItem;
import com.jidesoft.editor.status.CaretOverwriteStatusBarItem;
import com.jidesoft.editor.status.CaretStatusBarItem;
import com.jidesoft.editor.status.CaretViewPositionStatusBarItem;
import com.jidesoft.editor.status.CodeEditorStatusBar;
import com.jidesoft.editor.status.EditableStatusBarItem;
import com.jidesoft.editor.status.LineBreakStatusBarItem;


/**
 * SwingJideEditorConfig : Configures the Jide Editor into the Java SwingBuilder
 *
 * @author anavarro - 20 Jul 2009
 *
 */
public final class SwingJideEditorConfig
{

    /**
     * Constructor.
     *
     */
    private SwingJideEditorConfig()
    {
        // Helper Class
    }

    /**
     * Registers SwingX components into the default SwingBuilder
     */
    public static void register()
    {
        register(SwingJavaBuilder.getConfig());
    }

    /**
     * Registers SwingX components into the specified BuilderConfig
     *
     * @param config
     *            Builder configuration
     */
    public static void register(BuilderConfig config)
    {
        // visual components
        // editor
        config.addType(ClipboardsDialog.class);
        config.addType(CodeEditor.class);
        config.addType(CodeEditorDocumentPane.class);
        config.addType(CodeEditorPainter.class);
        config.addType(CodeEditorSearchable.class);
        config.addType(SyntaxDocument.class);
        // editor.margin
        config.addType(AbstractLineMargin.class);
        config.addType(AbstractMargin.class);
        config.addType(BraceMatchingMarginPainter.class);
        config.addType(CodeFoldingMargin.class);
        config.addType(LineNumberMargin.class);
        config.addType(LineOffsetMargin.class);
        config.addType(MarginArea.class);
        // editor.marker
        config.addType(MarkerArea.class);
        config.addType(MarkerEye.class);
        config.addType(MarkerStripe.class);
        // editor.settings
        config.addType(FontPanel.class);
        config.addType(StyleListPanel.class);
        config.addType(StylePanel.class);
        // editor.status
        config.addType(AbstractCodeEditorStatusBarItem.class);
        config.addType(CaretModelPositionStatusBarItem.class);
        config.addType(CaretOffsetStatusBarItem.class);
        config.addType(CaretOverwriteStatusBarItem.class);
        config.addType(CaretStatusBarItem.class);
        config.addType(CaretViewPositionStatusBarItem.class);
        config.addType(CodeEditorStatusBar.class);
        config.addType(EditableStatusBarItem.class);
        config.addType(LineBreakStatusBarItem.class);
    }
}
